
body {
  color: #000000;
  background-image: url('/brickwall.png');
  font-family: 'Ubuntu Mono', 'Droid Sans Mono', sans-serif;
  font-size: 1em;
}

#container {
    width: 960px;
    margin-left: auto;
    margin-right: auto;
    color: #000;
    background-color: #fff;
    -moz-box-shadow: 0 0 5px #888;
    -webkit-box-shadow: 0 0 5px#888;
    box-shadow: 0 0 5px #888;
}

#container p {
  padding: 15px;
}

#container .post-body {
  padding: 15px;
}

#container .post-body p {
  padding: 2px;
}

#container .post-list {
  padding: 15px;
}

#container .post-list ul {
  list-style-type: none;
  padding: 0;
}

#container .post-list li .postdate {
  background-color: #ddd;
}

#container .blog-form {
  width: 100%;
}

#container .blog-form .blog-form-control {
  width: 100%;
  border: 1px solid #000;
  font-family: 'Ubuntu Mono', sans-serif;
}

#container .blog-form .blog-form-control-textarea {
  height: 400px;
}

#container .blog-form .btn {
  width: 75px;
  height: 45px;
}

#container a {
    font-weight: bold;
    color: black;

}

.clearfix {
    clear:both;
}

a {
  color: rgb(80,0,0);
}
a:link {
  text-decoration: none; 
}
a:visited {
  text-decoration: none;
}
a:hover {
  text-decoration: underline;
}
a:active {
  text-decoration: none;
}

h1        { color: #333; font-family: 'Cabin Sketch', cursive; font-size: 42px; }
h2        { color: #999; }
h3 { 
    color: rgb(40,0,0); 
}
h4        { color: #aaa; }

#header {
    clear:both;
}

#header .logo {
    float:left;
    margin-left: 15px;
    margin-right: 15px;
}

#header .logo img {
  border-radius: 10px;
}

#footer {
  background-color: #000;
}

#footer a {
  color: #fff;
}

#footer p {
  text-indent: 0em;
  font-size: 75%;
  clear: none;
}

/* navbar */

#navbar {
  background-color: #000;
}

#navbar p {
  text-indent: 0em;
  font-size: 75%;
  clear: none;
}

#navbar a {
  color: #fff;
}
